## Description

Please describe the nature of your changes and link to the relevant issue(s) if applicable.

Fixes # (issue number if applicable)

## Checklist

Before submitting your pull request, please ensure the following:

- [ ] I have read the [CONTRIBUTING.md](https://github.com/razbuild/raztint/blob/main/CONTRIBUTING.md) guidelines.
- [ ] My code follows the project's style guidelines (passed linting).
- [ ] I have added tests to cover my changes (if applicable).
- [ ] All existing tests pass.
- [ ] Documentation has been updated (if necessary, for API changes).
- [ ] This PR does not introduce any breaking changes to the public API.

## Type of Change

- [ ] Bug fix (non-breaking change which fixes an issue)
- [ ] New feature (non-breaking change which adds functionality)
- [ ] Documentation update
- [ ] Code quality/refactoring (no change in functionality)